@@ -1,6 +1,7 @@
 from pathlib import Path
 from typing import Any, Dict, Optional, Tuple
 from codegraphcontext.utils.debug_log import debug_log, info_logger, error_logger, warning_logger, debug_logger
+from codegraphcontext.utils.tree_sitter_manager import execute_query
 
 RUBY_QUERIES = {
     "functions": """
@@ -28,8 +29,10 @@ RUBY_QUERIES = {
     """,
     "calls": """
         (call
+            receiver: (_)? @receiver
             method: (identifier) @name
-        )
+            arguments: (argument_list)? @args
+        ) @call_node
     """,
     "variables": """
         (assignment
@@ -62,11 +65,6 @@ class RubyTreeSitterParser:
         self.language = generic_parser_wrapper.language
         self.parser = generic_parser_wrapper.parser
 
-        self.queries = {
-            name: self.language.query(query_str)
-            for name, query_str in RUBY_QUERIES.items()
-        }
-
     def _get_node_text(self, node: Any) -> str:
         return node.text.decode("utf-8")
     
@@ -76,9 +74,9 @@ class RubyTreeSitterParser:
     
     def _find_modules(self, root_node: Any) -> list[Dict[str, Any]]:
         modules = []
-        query = self.queries["modules"]
+        query_str = RUBY_QUERIES["modules"]
         # name via captures
-        captures = list(query.captures(root_node))
+        captures = list(execute_query(self.language, query_str, root_node))
         for node, cap in captures:
             if cap == "module_node":
                 name = None
@@ -101,8 +99,8 @@ class RubyTreeSitterParser:
 
     def _find_module_inclusions(self, root_node: Any) -> list[Dict[str, Any]]:
         includes = []
-        query = self.queries["module_includes"]
-        for node, cap in query.captures(root_node):
+        query_str = RUBY_QUERIES["module_includes"]
+        for node, cap in execute_query(self.language, query_str, root_node):
             if cap == "method":
                 method_name = self._get_node_text(node)
                 if method_name != "include":
@@ -110,7 +108,7 @@ class RubyTreeSitterParser:
             if cap == "include_call":
                 method = None
                 module = None
-                for n, c in query.captures(node):
+                for n, c in execute_query(self.language, query_str, node):
                     if c == "method":
                         method = self._get_node_text(n)
                     elif c == "module":
@@ -211,10 +209,10 @@ class RubyTreeSitterParser:
     def _find_functions(self, root_node: Any) -> list[Dict[str, Any]]:
         """Find all function/method definitions."""
         functions = []
-        query = self.queries["functions"]
+        query_str = RUBY_QUERIES["functions"]
         
         # Collect all captures first
-        all_captures = list(query.captures(root_node))
+        all_captures = list(execute_query(self.language, query_str, root_node))
         
         # Group captures by function node using a different approach
         captures_by_function = {}
@@ -269,10 +267,10 @@ class RubyTreeSitterParser:
     def _find_classes(self, root_node: Any) -> list[Dict[str, Any]]:
         """Find all class and module definitions."""
         classes = []
-        query = self.queries["classes"]
+        query_str = RUBY_QUERIES["classes"]
         
         # Collect all captures first
-        all_captures = list(query.captures(root_node))
+        all_captures = list(execute_query(self.language, query_str, root_node))
         
         # Group captures by class node using a different approach
         captures_by_class = {}
@@ -323,10 +321,10 @@ class RubyTreeSitterParser:
     def _find_imports(self, root_node: Any) -> list[Dict[str, Any]]:
         """Find all require/load statements."""
         imports = []
-        query = self.queries["imports"]
+        query_str = RUBY_QUERIES["imports"]
         
         # Collect all captures first
-        all_captures = list(query.captures(root_node))
+        all_captures = list(execute_query(self.language, query_str, root_node))
         
         # Group captures by import node using a different approach
         captures_by_import = {}
@@ -380,21 +378,63 @@ class RubyTreeSitterParser:
     def _find_calls(self, root_node: Any) -> list[Dict[str, Any]]:
         """Find all function and method calls."""
         calls = []
-        query = self.queries["calls"]
+        query_str = RUBY_QUERIES["calls"]
         
-        for node, capture_name in query.captures(root_node):
-            if capture_name == 'name':
-                name = self._get_node_text(node)
-                full_name = name
+        # Collect all captures
+        all_captures = list(execute_query(self.language, query_str, root_node))
+        
+        # Group by call node
+        captures_by_call = {}
+        for node, capture_name in all_captures:
+            if capture_name == 'call_node':
+                captures_by_call[id(node)] = {'node': node, 'name': None, 'receiver': None, 'args': []}
+        
+        for node, capture_name in all_captures:
+             for call_id, call_data in captures_by_call.items():
+                call_node = call_data['node']
+                if not (node.start_byte >= call_node.start_byte and node.end_byte <= call_node.end_byte):
+                    continue
+
+                if capture_name == 'name':
+                     # The identifier could be part of receiver or arguments too, be careful
+                     # But tree-sitter structure ensures method name is distinct
+                     # Check if node is child 'method' of call_node
+                     if node == call_node.child_by_field_name('method'):
+                        captures_by_call[call_id]['name'] = self._get_node_text(node)
+                
+                elif capture_name == 'receiver':
+                    captures_by_call[call_id]['receiver'] = self._get_node_text(node)
+                
+                elif capture_name == 'args':
+                     # Capture arguments
+                    args_text = self._get_node_text(node)
+                    # Simple heuristic: split by comma
+                    captures_by_call[call_id]['args'] = [a.strip() for a in args_text.strip("()").split(',') if a.strip()]
+
+        for call_data in captures_by_call.values():
+            call_node = call_data['node']
+            name = call_data['name']
+            
+            if name:
+                receiver = call_data['receiver']
+                full_name = f"{receiver}.{name}" if receiver else name
+                
+                context_name, context_type, context_line = self._get_parent_context(call_node)
+                class_context = context_name if context_type in ('class', 'module') else None
+                if context_type == 'method':
+                     # If inside a method, try to find enclosing class too
+                     enclosing_class, _, _ = self._get_parent_context(call_node.parent, ('class', 'module'))
+                     class_context = enclosing_class
+
 
                 calls.append({
                     "name": name,
                     "full_name": full_name,
-                    "line_number": node.start_point[0] + 1,
-                    "args": [],  # Placeholder - could be enhanced to extract arguments
+                    "line_number": call_node.start_point[0] + 1,
+                    "args": call_data['args'],
                     "inferred_obj_type": None,
-                    "context": None,  # Placeholder
-                    "class_context": None,  # Placeholder
+                    "context": (context_name, context_type, context_line),
+                    "class_context": class_context,
                     "lang": self.language_name,
                     "is_dependency": False,
                 })
@@ -404,11 +444,11 @@ class RubyTreeSitterParser:
     def _find_variables(self, root_node: Any) -> list[Dict[str, Any]]:
         """Find all variable assignments."""
         variables = []
-        query = self.queries["variables"]
+        query_str = RUBY_QUERIES["variables"]
         
         # Group captures by assignment node
         captures_by_assignment = {}
-        for node, capture_name in query.captures(root_node):
+        for node, capture_name in execute_query(self.language, query_str, root_node):
             if capture_name == 'name':
                 # Find the parent assignment node
                 current = node.parent
@@ -473,14 +513,14 @@ def pre_scan_ruby(files: list[Path], parser_wrapper) -> dict:
             name: (identifier) @name
         )
     """
-    query = parser_wrapper.language.query(query_str)
+    
 
     for file_path in files:
         try:
             with open(file_path, "r", encoding="utf-8") as f:
                 tree = parser_wrapper.parser.parse(bytes(f.read(), "utf8"))
 
-            for capture, _ in query.captures(tree.root_node):
+            for capture, _ in execute_query(parser_wrapper.language, query_str, tree.root_node):
                 name = capture.text.decode('utf-8')
                 if name not in imports_map:
                     imports_map[name] = []
